@@ -226,9 +226,11 @@ def infMap_alg(df_graph):
 def graph_algoritm_selected(df_graph,selection,node_list):
 
     len_nodeList = len(node_list)
-    if(selection =="1 - GirvanNewman"):
+    if(selection ==1): #GirvanNewman
+        print("Girvan Newman");
         df_algComu = girvanNewman_alg(node_list,df_graph)
-    elif(selection =="2 - Leiden"):
+    elif(selection ==2): #Leiden
+        print("Leiden");                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                
         df_algComu = leiden_alg(df_graph)
     #elif(selection =="3"):
         #df_algComu = infMap_alg(df_graph)
@@ -937,9 +939,9 @@ def close_duplicates(data):
 	
 def text_to_list_features_conversor (data):
     for index, row in data.iterrows():
-        data["favorite_tweets_list"].iloc[index] = ast.literal_eval(data.loc[index, "favorite_tweets_list"])
-        data["retweet_tweets_list"].iloc[index] = ast.literal_eval(data.loc[index,"retweet_tweets_list"])
-        data["tw_per_day_list"].iloc[index] = ast.literal_eval(data.loc[index,"tw_per_day_list"])
+        #data["favorite_tweets_list"].iloc[index] = ast.literal_eval(data.loc[index, "favorite_tweets_list"])
+        #data["retweet_tweets_list"].iloc[index] = ast.literal_eval(data.loc[index,"retweet_tweets_list"])
+        #data["tw_per_day_list"].iloc[index] = ast.literal_eval(data.loc[index,"tw_per_day_list"])
         data["text_tweets_days_list"].iloc[index] = data.loc[index,"text_tweets_days_list"].replace('"', "'").replace("], [","?#??").strip("[]'").split("?#??")
         list_day = []                                                                                
         list_text_tweets_day = []
